#
# spec file for package lxqt-notificationd
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-notificationd
Version:        0.14.1
Release:        lp152.2.6
Summary:        LXQt Notification daemon
License:        LGPL-2.1-or-later
Group:          System/GUI/LXQt
URL:            http://www.lxqt.org
Source:         https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.1.0
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  lxqt-build-tools-devel >= 0.6.0
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5Xdg)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(lxqt) >= %{version}
Recommends:     %{name}-lang

%description
The LXQt Notification daemon

%lang_package

%prep
%setup -q
# Changing LXQt into X-LXQt in desktop files to be freedesktop compliant and shut rpmlint warnings
#find -name '*desktop.in*' -exec sed -ri 's/(LXQt;)/X-\1/' {} +

%build
%cmake -DPULL_TRANSLATIONS=No
make %{?_smp_mflags}

%install
%cmake_install
%fdupes -s %{buildroot}%{_datadir}

%find_lang %{name} --with-qt

%files
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/%{name}
%{_bindir}/lxqt-config-notificationd
%{_datadir}/applications/lxqt-config-notificationd.desktop
%{_sysconfdir}/xdg/autostart/lxqt-notifications.desktop

%files lang -f %{name}.lang 
%dir %{_datadir}/lxqt
%dir %{_datadir}/lxqt/translations
%dir %{_datadir}/lxqt/translations/lxqt-notificationd
%{_datadir}/lxqt/translations/lxqt-config-notificationd

%changelog
* Mon Jan 27 2020 Michael Vetter <mvetter@suse.com>
- bsc#1161365: Fix build
- Add buildrequire for glib
* Fri Mar  1 2019 mvetter@suse.com
- Update to 0.14.1:
  * Only translations was changed
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Notification history implemented
  * Implementations fixed:
  - Fixed notification styles
  - Don't use automatic string conversions
  - Use QLatin1String where it is more efficient
  - Test app updated
  * Improved cmake scripting
  - Set cmake_minimum_required to 3.1.0
  - Removed locale compile definitons
  * Moved translations from lxqt-l10n back to lxqt-notificationd
  - Removed obsolete translation fuctionality
  - Added translation promo in README.md
  * Translation updates
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * Spanish translation update
  * Include QStyle and QStyleOption to fix compilation with Qt5.11
  * CMake: Prevent in-source builds
  * notificationlayout: Remove the "on top" hint
  * fix razor-qt -> lxqt and http -> https
  * Fix mentions of LXDE
  * Fix typo
  * Fix spanish translation
  * Update Simplified Chinese desktop entry
  * Update Traditional Chinese translation
  * Drop Qt foreach
  * cmake: Handle CMP0071
  * Change icon to preferences-desktop-notification
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set patch version
  * Don't export github templates
  * Improvement for notification settings, see https://github.com/lxde/lxqt/issues/744#issuecomment-138601402
  * Updated Lithuanian language
  * Drops Qt5Core_VERSION_STRING
  * lxqt-config-notificationd: set Qt::AA_UseHighDpiPixmaps to true
  * Add a basic cli to lxqt-config-notificationd Add a basic cli to lxqt-notificationd
  * Added default CMAKE_BUILD_TYPE and LXQT_NOTIFICATION_PATCH_VERSION
  * Create lxqt-config-notificationd_pl_PL.desktop
  * Fixes a FTBFS in superbuild mode
  * Added merged autostart to CMakeLists.txt
  * Updated *_da.desktop files and removed *_da_DK.desktop files
  * Update desktop entries and Replace fr_FR by fr
  * Update Greek translation (el) Remove country variant from language code
  * CMake: Adds Runtime and Devel install COMPONENTs
  * Coding style changes
  * Updates the build system to use the Targets infrastructure
  * Drops hardcoded /etc/xdg paths
  * Updated german translation, replaced Qt4 by Qt in all xsession/translations
  * Updates translations infrastructure
  * Update the required minimum cmake version
  * remove dead template lines switch OnlyShowIn from Razor -> LXQt stringchanges LxQt -> LXQt
  * Support lxqt-session and add necessary xdg autostart desktop entry files.
  * Fix a typo: singals -> signals
  * Bump year
- Remove post and postun
* Thu Feb 23 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Updated da translation. Removed da_DK
  * Update and rename French .desktop file
  * Make CMakeList.txt more uniform.
  * Remove cpack (#53)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * Update and extend README.md
  * Add Catalan translation
  * build: Use external translations
  * ts-files removal (#50)
  * Clean up qDebugs/comments in notification.cpp
  * config: Use our specific icon for demo
  * Fix used licenses in AUTHORS, lxqt-notificationd is pure LGPL Bump year in AUTHORS
  * Italian translation update
  * Updated Russian translation Removed ru_RU files
  * notification: Default icon
  * notification: Fill background
  * update lxqt-config-notificationd_hu.ts
  * Update lxqt-config-notificationd_it.ts
* Sat Jul 30 2016 luke.nukem.jones@gmail.com
- Update summary and description to match the package.
* Fri Nov  6 2015 mvetter@suse.com
- Upstream release 0.10.0
- Removing patches:
  * fix_desktop_file.patch- Using sed in spec file now.
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed %%build and %%install to use cmake macros
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang subpackage
- Added patch
  + fix_desktop_file.patch
* Sun Jan 25 2015 sfalken@opensuse.org
- Added conditionals to enable Fedora builds
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 andrea@opensuse.org
- removed unused buildrequires
* Tue May 13 2014 sfalken@opensuse.org
- Specfile cleanup
* Mon May 12 2014 sfalken@opensuse.org
- Removed fedora specfile, split into subproject
  Del:  lxqt-notificationd-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- ran spec-cleaner on openSUSE specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  lxqt-notificationd-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  lxqt-notificationd-0.7.0.tar.xz
  Del:  _service
* Wed Apr  2 2014 sfalken@opensuse.org
- Removed direct cmake calls, in favour of %%cmake and %%cmake_install
* Wed Apr  2 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: lxqt-notificationd.spec
  Add: lxqt-notificationd.changes
